##  Related Information
  * [Automations with Scripts](https://help.sap.com/docs/leanix/ea/automations-with-scripts?locale=en-US&state=PRODUCTION&version=CLOUD "Use automations with scripts to update fact sheet fields or call SAP LeanIX APIs. Define the script logic in a script editor in SAP LeanIX.")
  * [Calculations](https://help.sap.com/docs/leanix/ea/calculations?locale=en-US&state=PRODUCTION&version=CLOUD "Calculations let you populate fact sheet fields based on values from other fields. Use calculation templates for common scenarios or configure your own to define custom logic.")
  * [Callbacks in Push Webhooks](https://help.sap.com/docs/leanix/ea/push-webhooks?locale=en-US&state=PRODUCTION&version=CLOUD#loio535b4b2790d5460fb013b94b6e0bd877__manipulating_the_webhook_payload_using_a_callback)


YesNo
Send
